@@ -1,8 +1,6 @@
 #ifndef GSL_TEST_H
 #define GSL_TEST_H
 
-#include <config.h>
-
 void
   gsl_test (int status, const char *test_description, ...);
 
@@ -10,6 +8,10 @@ void
 gsl_test_rel (double result, double expected, double relative_error,
 	      const char *test_description, ...) ;
 
+void
+gsl_test_abs (double result, double expected, double relative_error,
+	      const char *test_description, ...) ;
+
 void
 gsl_test_int (int result, int expected, const char *test_description, ...) ;
 
