@@ -1,20 +1,12 @@
-#include <config.h>
-#include <math.h>
-
-#include <gsl_complex.h>
-#include <gsl_fft_complex.h>
-
-#include "fft_complex.h"
-
 int
-fft_complex_pass_2 (const double in[],
-		    const size_t istride,
-		    double out[],
-		    const size_t ostride,
-		    const gsl_fft_direction sign,
-		    const size_t product,
-		    const size_t n,
-		    const gsl_complex twiddle[])
+FUNCTION(fft_complex,pass_2) (const BASE in[],
+			      const size_t istride,
+			      BASE out[],
+			      const size_t ostride,
+			      const gsl_fft_direction sign,
+			      const size_t product,
+			      const size_t n,
+			      const gsl_complex twiddle[])
 {
   size_t i = 0, j = 0;
   size_t k, k1;
