@@ -1,9 +1,10 @@
+#include <config.h>
 #include <stdlib.h>
 #include <gsl_errno.h>
 #include <gsl_integration.h>
 
 int
-gsl_integration_qagse (double (*f)(double x),
+gsl_integration_qagse (const gsl_function *f,
 		       double a, double b,
 		       double epsabs, double epsrel,
 		       gsl_integration_workspace * workspace,
