@@ -1,8 +1,9 @@
+#include <config.h>
 #include <gsl_integration.h>
 #include "qk31.h"
 
 void
-gsl_integration_qk31 (double (*f) (double x),
+gsl_integration_qk31 (const gsl_function *f,
 		      double a, double b,
 		      double * result, double * abserr,
 		      double * resabs, double * resasc)
