@@ -1,29 +1,28 @@
 /* Author:  G. Jungman
- * RCS:     $Id: bsearch.h,v 1.2 1998/07/05 06:48:52 jungman Exp $
+ * RCS:     $Id: bsearch.h,v 1.3 1998/11/14 02:10:49 bjg Exp $
  */
 #ifndef GSL_INTERP_BSEARCH_H_
 #define GSL_INTERP_BSEARCH_H_
 
-
-unsigned long
+size_t
 interp_bsearch(const double x_array[], double x,
-               unsigned long index_lo,
-               unsigned long index_hi
+               size_t index_lo,
+               size_t index_hi
                );
 
 #ifdef HAVE_INLINE
 extern
 inline
-unsigned long
+size_t
 interp_bsearch(const double x_array[], double x,
-               unsigned long index_lo,
-               unsigned long index_hi
+               size_t index_lo,
+               size_t index_hi
                )
 {
-  int ilo = index_lo;
-  int ihi = index_hi;
-  while(ihi - ilo > 1) {
-    int i = (ihi + ilo)/2;
+  size_t ilo = index_lo;
+  size_t ihi = index_hi;
+  while(ihi > ilo + 1) {
+    size_t i = (ihi + ilo)/2;
     if(x_array[i] > x)
       ihi = i;
     else
