@@ -1,7 +1,3 @@
-#include <stdlib.h>
-#include <gsl_matrix.h>
-
-
 TYPE (gsl_matrix) *
 FUNCTION (gsl_matrix, alloc) (const size_t n1, const size_t n2)
 {
