@@ -1,5 +1,3 @@
-#include <gsl_errno.h>
-
 int
 FUNCTION (gsl_matrix, copy_row) (const TYPE (gsl_matrix) * m,
 				 const size_t i,
@@ -34,40 +32,6 @@ FUNCTION (gsl_matrix, copy_row) (const TYPE (gsl_matrix) * m,
   return 0;
 }
 
-int
-FUNCTION (gsl_matrix, get_row) (const TYPE (gsl_matrix) * m,
-				const size_t i,
-				TYPE (gsl_vector) * v)
-{
-  const size_t column_length = m->size1;
-  const size_t row_length = m->size2;
-
-  if (i >= column_length)
-    {
-      GSL_ERROR ("row index is out of range", GSL_EINVAL);
-    }
-
-  if (v->size != row_length)
-    {
-      GSL_ERROR ("matrix row size and vector length are not equal",
-		 GSL_EBADLEN);
-    }
-
-  {
-    ATOMIC *row_data = m->data + MULTIPLICITY * i * row_length;
-    size_t j;
-
-    for (j = 0; j < MULTIPLICITY * row_length; j++)
-      {
-	v->data[j] = row_data[j];
-      }
-  }
-
-  v->stride = 1;
-
-  return 0;
-}
-
 int
 FUNCTION (gsl_matrix, copy_col) (const TYPE (gsl_matrix) * m,
 				 const size_t j,
