@@ -1,6 +1,8 @@
+#include <config.h>
 #include <stdio.h>
 #include <math.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <gsl_rng.h>
 #include <gsl_siman.h>
@@ -30,65 +32,57 @@ gsl_siman_solve (const gsl_rng * r, void *x0_p, gsl_Efunc_t Ef,
   memcpy (x, x0_p, element_size);
   done = 0;
 
-  if (print_position)
-    {
-      printf ("#-iter  #-evals   temperature     position   energy\n");
+  if (print_position) {
+    printf ("#-iter  #-evals   temperature     position   energy\n");
+  }
+
+  while (!done) {
+    E = Ef (x);
+    n_accepts = 0;
+    n_rejects = 0;
+    n_eless = 0;
+    for (i = 0; i < params.n_tries - 1; ++i) {
+      memcpy (new_x, x, element_size);
+      take_step (r, new_x, params.step_size);
+      new_E = Ef (new_x);
+      ++n_evals;		/* keep track of Ef() evaluations */
+      /* now take the crucial step: see if the new point is accepted
+	 or not, as determined by the boltzman probability */
+      if (new_E < E) {
+	/* yay! take a step */
+	memcpy (x, new_x, element_size);
+	E = new_E;
+	++n_eless;
+      } else if (exp (-(E - new_E) / (params.k * T))
+		 * gsl_rng_uniform (r) < 0.5) {
+	/* yay! take a step */
+	memcpy (x, new_x, element_size);
+	E = new_E;
+	++n_accepts;
+      } else {
+	++n_rejects;
+      }
     }
 
-  while (!done)
-    {
-      E = Ef (x);
-      n_accepts = 0;
-      n_rejects = 0;
-      n_eless = 0;
-      for (i = 0; i < params.n_tries - 1; ++i)
-	{
-	  memcpy (new_x, x, element_size);
-	  take_step (r, new_x, params.step_size);
-	  new_E = Ef (new_x);
-	  ++n_evals;		/* keep track of Ef() evaluations */
-	  /* now take the crucial step: see if the new point is accepted
-	     or not, as determined by the boltzman probability */
-	  if (new_E < E)
-	    {
-	      /* yay! take a step */
-	      memcpy (x, new_x, element_size);
-	      E = new_E;
-	      ++n_eless;
-	    }
-	  else if (exp (-(E - new_E) / (params.k * T)) * gsl_rng_uniform (r) < 0.5)
-	    {
-	      /* yay! take a step */
-	      memcpy (x, new_x, element_size);
-	      E = new_E;
-	      ++n_accepts;
-	    }
-	  else
-	    {
-	      ++n_rejects;
-	    }
-	}
-
-      if (print_position)
-	{			/* see if we need to print stuff as we go */
-/*       printf("%5d %12g %5d %3d %3d %3d", n_iter, T, n_evals, */
-/*           100*n_eless/n_steps, 100*n_accepts/n_steps, */
-/*           100*n_rejects/n_steps); */
-	  printf ("%5d   %7d  %12g", n_iter, n_evals, T);
-	  print_position (x);
-	  printf ("  %12g\n", E);
-	}
-
-      /* apply the cooling schedule to the temperature */
-      /* FIXME: I should also introduce a cooling schedule for the n_tries */
-      T /= params.mu_t;
-      ++n_iter;
-      if (T < params.t_min)
-	{
-	  done = 1;
-	}
+    if (print_position) {
+      /* see if we need to print stuff as we go */
+      /*       printf("%5d %12g %5d %3d %3d %3d", n_iter, T, n_evals, */
+      /*           100*n_eless/n_steps, 100*n_accepts/n_steps, */
+      /*           100*n_rejects/n_steps); */
+      printf ("%5d   %7d  %12g", n_iter, n_evals, T);
+      print_position (x);
+      printf ("  %12g\n", E);
     }
 
+    /* apply the cooling schedule to the temperature */
+    /* FIXME: I should also introduce a cooling schedule for the n_tries */
+    T /= params.mu_t;
+    ++n_iter;
+    if (T < params.t_min) {
+      done = 1;
+    }
+  }
+
   /* at the end, copy the result onto the initial point, so we pass it
      back to the caller */
   memcpy (x0_p, x, element_size);
@@ -116,11 +110,10 @@ gsl_siman_solve_many (const gsl_rng * r, void *x0_p, gsl_Efunc_t Ef,
   double u;			/* throw the die to choose a new "x" */
   int n_iter;
 
-  if (print_position)
-    {
-      printf ("#-iter    temperature       position");
-      printf ("         delta_pos        energy\n");
-    }
+  if (print_position) {
+    printf ("#-iter    temperature       position");
+    printf ("         delta_pos        energy\n");
+  }
 
   x = (void *) malloc (params.n_tries * element_size);
   new_x = (void *) malloc (params.n_tries * element_size);
