@@ -1,7 +1,7 @@
 /* Author:  G. Jungman
- * RCS:     $Id: bessel_I0.c,v 1.18 1998/08/18 21:15:12 jungman Exp $
+ * RCS:     $Id: bessel_I0.c,v 1.24 1999/01/17 21:55:54 jungman Exp $
  */
-#include <math.h>
+#include <config.h>
 #include <gsl_math.h>
 #include <gsl_errno.h>
 #include "gsl_sf_chebyshev.h"
@@ -37,8 +37,8 @@
 
 static double bi0_data[12] = {
   -.07660547252839144951,
-  1.927337953993808270,
-   .2282644586920301339, 
+  1.92733795399380827000,
+   .22826445869203013390, 
    .01304891466707290428,
    .00043442709008164874,
    .00000942265768600193,
@@ -49,12 +49,13 @@ static double bi0_data[12] = {
    .00000000000000053339,
    .00000000000000000245
 };
-static struct gsl_sf_cheb_series bi0_cs = {
+static gsl_sf_cheb_series bi0_cs = {
   bi0_data,
   11,
   -1, 1,
   (double *)0,
-  (double *)0
+  (double *)0,
+  11
 };
 
 static double ai0_data[21] = {
@@ -80,12 +81,13 @@ static double ai0_data[21] = {
   -.00000000000000071,
    .00000000000000007
 };
-static struct gsl_sf_cheb_series ai0_cs = {
+static gsl_sf_cheb_series ai0_cs = {
   ai0_data,
   20,
   -1, 1,
   (double *)0,
-  (double *)0
+  (double *)0,
+  13
 };
 
 static double ai02_data[22] = {
@@ -112,58 +114,87 @@ static double ai02_data[22] = {
   -.00000000000000027,
    .00000000000000003
 };
-static struct gsl_sf_cheb_series ai02_cs = {
+static gsl_sf_cheb_series ai02_cs = {
   ai02_data,
   21,
   -1, 1,
   (double *)0,
-  (double *)0
+  (double *)0,
+  11
 };
 
 
 /*-*-*-*-*-*-*-*-*-*-*-* (semi)Private Implementations *-*-*-*-*-*-*-*-*-*-*-*/
 
-int gsl_sf_bessel_I0_scaled_impl(const double x, double * result)
+int gsl_sf_bessel_I0_scaled_impl(const double x, gsl_sf_result * result)
 {
   double y = fabs(x);
 
-  if(y < 2.0 * GSL_SQRT_MACH_EPS) {
-    *result = 1.;
+  if(result == 0) {
+    return GSL_EFAULT;
+  }
+  else if(y < 2.0 * GSL_SQRT_DBL_EPSILON) {
+    result->val = 1.0;
+    result->err = 0.5*y*y;
+    return GSL_SUCCESS;
   }
   else if(y <= 3.0) {
-    *result = exp(-y) * (2.75 + gsl_sf_cheb_eval(&bi0_cs, y*y/4.5-1.0));
+    const double ey = exp(-y);
+    gsl_sf_result c;
+    gsl_sf_cheb_eval_impl(&bi0_cs, y*y/4.5-1.0, &c);
+    result->val = ey * (2.75 + c.val);
+    result->err = GSL_DBL_EPSILON * fabs(result->val) + ey * c.err;
+    return GSL_SUCCESS;
   }
   else if(y <= 8.0) {
-    *result = (.375 + gsl_sf_cheb_eval(&ai0_cs, (48.0/y-11.0)/5.0)) / sqrt(y);
+    const double sy = sqrt(y);
+    gsl_sf_result c;
+    gsl_sf_cheb_eval_impl(&ai0_cs, (48.0/y-11.0)/5.0, &c);
+    result->val = (0.375 + c.val) / sy;
+    result->err = GSL_DBL_EPSILON * fabs(result->val) + c.err / sy;
+    return GSL_SUCCESS;
   }
   else {
-    *result = (.375 + gsl_sf_cheb_eval(&ai02_cs, 16.0/y-1.0)) / sqrt(y);
+    const double sy = sqrt(y);
+    gsl_sf_result c;
+    gsl_sf_cheb_eval_impl(&ai02_cs, 16.0/y-1.0, &c);
+    result->val = (0.375 + c.val) / sy;
+    result->err = GSL_DBL_EPSILON * fabs(result->val) + c.err / sy;
+    return GSL_SUCCESS;
   }
-  return GSL_SUCCESS;
 }
 
-int gsl_sf_bessel_I0_impl(const double x, double * result)
+
+int gsl_sf_bessel_I0_impl(const double x, gsl_sf_result * result)
 {
-  const double x_small = 2. * GSL_SQRT_MACH_EPS;
-  const double xmax    = GSL_LOG_DBL_MAX - 1.;   /* alog (r1mach(2)) */
   double y = fabs(x);
 
-  if(y < x_small) {
-    *result = 1.;
+  if(result == 0) {
+    return GSL_EFAULT;
+  }
+  else if(y < 2.0 * GSL_SQRT_DBL_EPSILON) {
+    result->val = 1.0;
+    result->err = 0.5*y*y;
     return GSL_SUCCESS;
   }
   else if(y <= 3.0) {
-    *result = 2.75 + gsl_sf_cheb_eval(&bi0_cs, y*y/4.5-1.0);
+    gsl_sf_result c;
+    gsl_sf_cheb_eval_impl(&bi0_cs, y*y/4.5-1.0, &c);
+    result->val = 2.75 + c.val;
+    result->err = GSL_DBL_EPSILON * fabs(result->val) + c.err;
     return GSL_SUCCESS;
   }
-  else if(y < xmax) {
-    double b_scaled;
+  else if(y < GSL_LOG_DBL_MAX - 1.0) {
+    const double ey = exp(y);
+    gsl_sf_result b_scaled;
     gsl_sf_bessel_I0_scaled_impl(x, &b_scaled);
-    *result = exp(y) * b_scaled;
+    result->val = ey * b_scaled.val;
+    result->err = GSL_DBL_EPSILON * fabs(result->val) + ey * b_scaled.err;
     return GSL_SUCCESS;
   }
   else {
-    *result = 0.0; /* FIXME: should be Inf */
+    result->val = 0.0; /* FIXME: should be Inf */
+    result->err = 0.0;
     return GSL_EOVRFLW;
   }
 }
@@ -171,16 +202,16 @@ int gsl_sf_bessel_I0_impl(const double x, double * result)
 
 /*-*-*-*-*-*-*-*-*-*-*-* Functions w/ Error Handling *-*-*-*-*-*-*-*-*-*-*-*/
 
-int gsl_sf_bessel_I0_scaled_e(const double x, double * result)
+int gsl_sf_bessel_I0_scaled_e(const double x, gsl_sf_result * result)
 {
   int status = gsl_sf_bessel_I0_scaled_impl(x, result);  
   if(status != GSL_SUCCESS) {
-    GSL_ERROR("gsl_sf_bessel_I0_e", status);
+    GSL_ERROR("gsl_sf_bessel_I0_scaled_e", status);
   }
   return status;
 }
 
-int gsl_sf_bessel_I0_e(const double x, double * result)
+int gsl_sf_bessel_I0_e(const double x, gsl_sf_result * result)
 {
   int status = gsl_sf_bessel_I0_impl(x, result);  
   if(status != GSL_SUCCESS) {
@@ -188,27 +219,3 @@ int gsl_sf_bessel_I0_e(const double x, double * result)
   }
   return status;
 }
-
-
-/*-*-*-*-*-*-*-*-*-*-*-* Functions w/ Natural Prototypes *-*-*-*-*-*-*-*-*-*-*-*/
-
-double gsl_sf_bessel_I0_scaled(const double x)
-{
-  double y;
-  int status = gsl_sf_bessel_I0_scaled_impl(x, &y);
-  if(status != GSL_SUCCESS) {
-    GSL_WARNING("gsl_sf_bessel_I0_scaled", status);
-  }
-  return y;
-}
-
-
-double gsl_sf_bessel_I0(const double x)
-{
-  double y;
-  int status = gsl_sf_bessel_I0_impl(x, &y);
-  if(status != GSL_SUCCESS) {
-    GSL_WARNING("gsl_sf_bessel_I0", status);
-  }
-  return y;
-}
