@@ -1,24 +1,18 @@
 /* Author:  G. Jungman
- * RCS:     $Id: chebyshev.c,v 1.14 1998/08/18 21:15:15 jungman Exp $
+ * RCS:     $Id: chebyshev.c,v 1.20 1999/01/17 21:56:03 jungman Exp $
  */
+#include <config.h>
 #include <stdlib.h>
-#include <math.h>
-#include <gsl_errno.h>
 #include <gsl_math.h>
+#include <gsl_errno.h>
 #include "gsl_sf_chebyshev.h"
 
-#define gslMAX(a,b) ((a) > (b) ? (a) : (b))
-#define gslMIN(a,b) ((a) < (b) ? (a) : (b))
-
-
-int gsl_sf_cheb_calc_impl(struct gsl_sf_cheb_series *, double (*)(double));
-
 
 /*-*-*-*-*-*-*-*-*-*-*-* Allocators *-*-*-*-*-*-*-*-*-*-*-*/
 
-struct gsl_sf_cheb_series * gsl_sf_cheb_new(double (*func)(double),
-    	    	    	    	    	    const double a, const double b,
-			      	    	    const int order)
+gsl_sf_cheb_series * gsl_sf_cheb_new(double (*func)(double),
+    	    	    	    	     const double a, const double b,
+			      	     const int order)
 {
   int status;
 
@@ -28,12 +22,15 @@ struct gsl_sf_cheb_series * gsl_sf_cheb_new(double (*func)(double),
   else if(a >= b) {
     GSL_ERROR_RETURN("gsl_sf_cheb_new: null interval, a>=b", GSL_EDOM, 0);
   }
-  else if(fabs(b-a) < 1.e+6 * GSL_MACH_EPS) {
+#if 0
+  else if(fabs(b-a) < 1.0e+6 * GSL_MACH_EPS) {
+    /* FIXME: arbitrary nonsense */
     GSL_ERROR_RETURN("gsl_sf_cheb_new: interval close to null", GSL_EFAILED, 0);
   }
+#endif
   else {
-    struct gsl_sf_cheb_series * cs = (struct gsl_sf_cheb_series *)
-      malloc(sizeof(struct gsl_sf_cheb_series));
+    gsl_sf_cheb_series * cs = (gsl_sf_cheb_series *)
+      malloc(sizeof(gsl_sf_cheb_series));
   
     if(cs == 0) {
       GSL_ERROR_RETURN("gsl_sf_cheb_new: out of memory", GSL_ENOMEM, 0);
@@ -42,14 +39,15 @@ struct gsl_sf_cheb_series * gsl_sf_cheb_new(double (*func)(double),
     cs->cp = (double *)0;
     cs->ci = (double *)0;
 
-    cs->order = order;
+    cs->order    = order;
+    cs->order_sp = order;
     cs->a = a;
     cs->b = b;
-    cs->c = malloc((order+1) * sizeof(double));
+    cs->c = (double *) malloc((order+1) * sizeof(double));
     if(cs->c == 0) {
       GSL_ERROR_RETURN("gsl_sf_cheb_new: out of memory", GSL_ENOMEM, 0);
     }
-  
+
     status = gsl_sf_cheb_calc_impl(cs, func);
     if(status != GSL_SUCCESS) {
       free(cs);
@@ -64,7 +62,7 @@ struct gsl_sf_cheb_series * gsl_sf_cheb_new(double (*func)(double),
 
 /*-*-*-*-*-*-*-*-*-*-*-* (semi)Private Implementations *-*-*-*-*-*-*-*-*-*-*-*/
 
-int gsl_sf_cheb_calc_impl(struct gsl_sf_cheb_series * cs, double (*func)(double))
+int gsl_sf_cheb_calc_impl(gsl_sf_cheb_series * cs, double (*func)(double))
 {
   if(cs == 0) {
     return GSL_EFAULT;
@@ -73,8 +71,8 @@ int gsl_sf_cheb_calc_impl(struct gsl_sf_cheb_series * cs, double (*func)(double)
     int k, j;
     double bma = 0.5 * (cs->b - cs->a);
     double bpa = 0.5 * (cs->b + cs->a);
-    double fac = 2./(cs->order +1.);
-    double * f = malloc((cs->order+1) * sizeof(double));
+    double fac = 2.0/(cs->order +1.0);
+    double * f = (double *) malloc((cs->order+1) * sizeof(double));
 
     if(f == 0) {
       return GSL_ENOMEM;
@@ -96,14 +94,14 @@ int gsl_sf_cheb_calc_impl(struct gsl_sf_cheb_series * cs, double (*func)(double)
   }
 }
 
-int gsl_sf_cheb_calc_deriv_impl(struct gsl_sf_cheb_series * cs)
+int gsl_sf_cheb_calc_deriv_impl(gsl_sf_cheb_series * cs)
 {
+  const int n = cs->order + 1;
+  const double con = 2.0 / (cs->b - cs->a);
   int j;
-  int n = cs->order + 1;
-  double con = 2. / (cs->b - cs->a);
   
   if(cs->cp != 0) free(cs->cp);
-  cs->cp = (double *)malloc(n * sizeof(double));
+  cs->cp = (double *) malloc(n * sizeof(double));
   if(cs->cp == 0) return GSL_ENOMEM;
 
   cs->cp[n-1] = 0.0;
@@ -116,13 +114,13 @@ int gsl_sf_cheb_calc_deriv_impl(struct gsl_sf_cheb_series * cs)
   return GSL_SUCCESS;
 }
 
-int gsl_sf_cheb_calc_integ_impl(struct gsl_sf_cheb_series * cs)
+int gsl_sf_cheb_calc_integ_impl(gsl_sf_cheb_series * cs)
 {
-  int n = cs->order + 1;
-  double con = 0.25 * (cs->b - cs->a);
+  const int n = cs->order + 1;
+  const double con = 0.25 * (cs->b - cs->a);
   
   if(cs->ci != 0) free(cs->ci);
-  cs->ci = (double *)malloc(n * sizeof(double));
+  cs->ci = (double *) malloc(n * sizeof(double));
   if(cs->ci == 0) return GSL_ENOMEM;
 
   if(n == 1) {
@@ -130,7 +128,7 @@ int gsl_sf_cheb_calc_integ_impl(struct gsl_sf_cheb_series * cs)
   }
   else if(n == 2) {
     cs->ci[1] = con * cs->c[0];
-    cs->ci[0] = 2. * cs->ci[1];
+    cs->ci[0] = 2.0 * cs->ci[1];
   }
   else {
     double sum = 0.0;
@@ -143,73 +141,121 @@ int gsl_sf_cheb_calc_integ_impl(struct gsl_sf_cheb_series * cs)
     }
     cs->ci[n-1] = con * cs->c[n-2]/(n-1);
     sum += fac * cs->ci[n-1];
-    cs->ci[0] = 2. * sum;
+    cs->ci[0] = 2.0 * sum;
   }
   return GSL_SUCCESS;
 }
 
 
-/*-*-*-*-*-*-*-*-*-*-*-* Functions w/ Error Handling *-*-*-*-*-*-*-*-*-*-*-*/
 
-int gsl_sf_cheb_calc_e(struct gsl_sf_cheb_series * cs, double (*func)(double))
-{
-  int status = gsl_sf_cheb_calc_impl(cs, func);
-  if(status != GSL_SUCCESS) {
-    GSL_ERROR("gsl_sf_cheb_calc_e", status);
-  }
-  return status;
-}
-
-
-/*-*-*-*-*-*-*-*-*-*-*-* Functions w/ Natural Prototypes *-*-*-*-*-*-*-*-*-*-*-*/
-
-
-double gsl_sf_cheb_eval_n(const struct gsl_sf_cheb_series * cs, const int n, const double x)
+int
+gsl_sf_cheb_eval_n_impl(const gsl_sf_cheb_series * cs,
+                        const int n, const double x,
+                        gsl_sf_result * result)
 {
   int j;
-  double d  = 0.;
-  double dd = 0.;
+  double d  = 0.0;
+  double dd = 0.0;
 
   double y  = (2.*x - cs->a - cs->b) / (cs->b - cs->a);
-  double y2 = 2. * y;
+  double y2 = 2.0 * y;
+
+  int eval_order = GSL_MAX_INT(0, GSL_MIN_INT(n, cs->order));
 
-  int eval_order = gslMIN(n, cs->order);
-  eval_order     = gslMAX(eval_order, 0);
-  
   for(j = eval_order; j>=1; j--) {
     double temp = d;
     d = y2*d - dd + cs->c[j];
     dd = temp;
   }
-  return y*d - dd + 0.5 * cs->c[0];
+
+  if(result == 0) {
+    return GSL_EFAULT;
+  }
+  else {
+    result->val = y*d - dd + 0.5 * cs->c[0];
+    result->err = fabs(cs->c[eval_order]);
+    return GSL_SUCCESS;
+  }
 }
 
-double gsl_sf_cheb_eval(const struct gsl_sf_cheb_series * cs, const double x)
+
+int
+gsl_sf_cheb_eval_impl(const gsl_sf_cheb_series * cs,
+                      const double x,
+                      gsl_sf_result * result)
 {
   int j;
-  double d  = 0.;
-  double dd = 0.;
+  double d  = 0.0;
+  double dd = 0.0;
 
-  double y  = (2.*x - cs->a - cs->b) / (cs->b - cs->a);
-  double y2 = 2. * y;
+  double y  = (2.0*x - cs->a - cs->b) / (cs->b - cs->a);
+  double y2 = 2.0 * y;
 
   for(j = cs->order; j>=1; j--) {
     double temp = d;
     d = y2*d - dd + cs->c[j];
     dd = temp;
   }
-  return y*d - dd + 0.5 * cs->c[0];
+
+  if(result == 0) {
+    return GSL_EFAULT;
+  }
+  else {
+    result->val = y*d - dd + 0.5 * cs->c[0];
+    result->err = GSL_DBL_EPSILON * fabs(result->val) + fabs(cs->c[cs->order]);
+    return GSL_SUCCESS;
+  }
 }
 
-double gsl_sf_cheb_eval_deriv(struct gsl_sf_cheb_series * cs, const double x)
+
+int
+gsl_sf_cheb_eval_mode_impl(const gsl_sf_cheb_series * cs,
+                           const double x,
+                           gsl_mode_t mode,
+                           gsl_sf_result * result)
 {
   int j;
-  double d  = 0.;
-  double dd = 0.;
+  double d  = 0.0;
+  double dd = 0.0;
+
+  double y  = (2.*x - cs->a - cs->b) / (cs->b - cs->a);
+  double y2 = 2.0 * y;
+
+  int eval_order;
+
+  if(GSL_MODE_PREC(mode) == GSL_PREC_DOUBLE)
+    eval_order = cs->order;
+  else
+    eval_order = cs->order_sp;
+
+  for(j = eval_order; j>=1; j--) {
+    double temp = d;
+    d = y2*d - dd + cs->c[j];
+    dd = temp;
+  }
+
+  if(result == 0) {
+    return GSL_EFAULT;
+  }
+  else {
+    result->val = y*d - dd + 0.5 * cs->c[0];
+    result->err = GSL_DBL_EPSILON * fabs(result->val) + fabs(cs->c[eval_order]);
+    return GSL_SUCCESS;
+  }
+}
+
+
+int
+gsl_sf_cheb_eval_deriv_impl(gsl_sf_cheb_series * cs, const double x,
+                            gsl_sf_result * result)
+{
+  int j;
+  double d  = 0.0;
+  double dd = 0.0;
 
   double y  = (2.0*x - cs->a - cs->b) / (cs->b - cs->a);
   double y2 = 2.0 * y;
-  
+
   if(cs->cp == (double *)0) gsl_sf_cheb_calc_deriv_impl(cs);
 
   for(j = cs->order; j>=1; j--) {
@@ -217,17 +263,28 @@ double gsl_sf_cheb_eval_deriv(struct gsl_sf_cheb_series * cs, const double x)
     d = y2*d - dd + cs->cp[j];
     dd = temp;
   }
-  return y*d - dd + 0.5 * cs->cp[0];
+
+  if(result == 0) {
+    return GSL_EFAULT;
+  }
+  else {
+    result->val = y*d - dd + 0.5 * cs->cp[0];
+    result->err = GSL_DBL_EPSILON * fabs(result->val) + fabs(cs->cp[cs->order]);
+    return GSL_SUCCESS;
+  }
 }
 
-double gsl_sf_cheb_eval_integ(struct gsl_sf_cheb_series * cs, const double x)
+
+int
+gsl_sf_cheb_eval_integ_impl(gsl_sf_cheb_series * cs, const double x,
+                            gsl_sf_result * result)
 {
   int j;
-  double d  = 0.;
-  double dd = 0.;
+  double d  = 0.0;
+  double dd = 0.0;
 
-  double y  = (2.*x - cs->a - cs->b) / (cs->b - cs->a);
-  double y2 = 2. * y;
+  double y  = (2.0*x - cs->a - cs->b) / (cs->b - cs->a);
+  double y2 = 2.0 * y;
   
   if(cs->ci == (double *)0) gsl_sf_cheb_calc_integ_impl(cs);
 
@@ -236,10 +293,68 @@ double gsl_sf_cheb_eval_integ(struct gsl_sf_cheb_series * cs, const double x)
     d = y2*d - dd + cs->ci[j];
     dd = temp;
   }
-  return y*d - dd + 0.5 * cs->ci[0];
+
+  if(result == 0) {
+    return GSL_EFAULT;
+  }
+  else {
+    result->val = y*d - dd + 0.5 * cs->ci[0];
+    result->err = GSL_DBL_EPSILON * fabs(result->val) + fabs(cs->ci[cs->order]);
+    return GSL_SUCCESS;
+  }
 }
 
-void gsl_sf_cheb_free(struct gsl_sf_cheb_series * cs)
+
+/*-*-*-*-*-*-*-*-*-*-*-* Functions w/ Error Handling *-*-*-*-*-*-*-*-*-*-*/
+
+int gsl_sf_cheb_calc_e(gsl_sf_cheb_series * cs, double (*func)(double))
+{
+  int status = gsl_sf_cheb_calc_impl(cs, func);
+  if(status != GSL_SUCCESS) {
+    GSL_ERROR("gsl_sf_cheb_calc_e", status);
+  }
+  return status;
+}
+
+int gsl_sf_cheb_eval_e(const gsl_sf_cheb_series * cs, double x, gsl_sf_result * r)
+{
+  int status = gsl_sf_cheb_eval_impl(cs, x, r);
+  if(status != GSL_SUCCESS) {
+    GSL_ERROR("gsl_sf_cheb_eval_e", status);
+  }
+  return status;
+}
+
+int gsl_sf_cheb_eval_n_e(const gsl_sf_cheb_series * cs, int order, double x, gsl_sf_result * r)
+{
+  int status = gsl_sf_cheb_eval_n_impl(cs, order, x, r);
+  if(status != GSL_SUCCESS) {
+    GSL_ERROR("gsl_sf_cheb_eval_n_e", status);
+  }
+  return status;
+}
+
+int gsl_sf_cheb_eval_deriv_e(gsl_sf_cheb_series * cs, double x, gsl_sf_result * r)
+{
+  int status = gsl_sf_cheb_eval_deriv_impl(cs, x, r);
+  if(status != GSL_SUCCESS) {
+    GSL_ERROR("gsl_sf_cheb_eval_deriv_e", status);
+  }
+  return status;
+}
+
+int gsl_sf_cheb_eval_integ_e(gsl_sf_cheb_series * cs, double x, gsl_sf_result * r)
+{
+  int status = gsl_sf_cheb_eval_integ_impl(cs, x, r);
+  if(status != GSL_SUCCESS) {
+    GSL_ERROR("gsl_sf_cheb_eval_integ_e", status);
+  }
+  return status;
+}
+
+/*-*-*-*-*-*-*-*-*-*-*-* Functions w/ Natural Prototypes *-*-*-*-*-*-*-*-*/
+
+void gsl_sf_cheb_free(gsl_sf_cheb_series * cs)
 {
   if(cs != 0) {
     if(cs->c != 0) free(cs->c);
