@@ -1,6 +1,7 @@
 /* Author:  G. Jungman
- * RCS:     $Id: dawson.c,v 1.2 1998/08/18 22:39:34 jungman Exp $
+ * RCS:     $Id: dawson.c,v 1.7 1998/12/14 01:12:39 jungman Exp $
  */
+#include <config.h>
 #include <gsl_math.h>
 #include <gsl_errno.h>
 #include "gsl_sf_chebyshev.h"
@@ -53,6 +54,15 @@ static double daw_data[21] = {
    -0.7345836823178450261333333333333e-29,
     0.8951937667516552533333333333333e-31
 };
+static gsl_sf_cheb_series daw_cs = {
+  daw_data,
+  15, /* 20, */
+  -1, 1,
+  (double *)0,
+  (double *)0,
+  9
+};
+
 static double daw2_data[45] = {
   -0.56886544105215527114160533733674e-01,
   -0.31811346996168131279322878048822e+00,
@@ -100,6 +110,15 @@ static double daw2_data[45] = {
   -0.18079295866694391771955199999999e-30,
    0.16090686015283030305450666666666e-31
 };
+static gsl_sf_cheb_series daw2_cs = {
+  daw2_data,
+  32, /* 44, */
+  -1, 1,
+  (double *)0,
+  (double *)0,
+  21
+};
+
 static double dawa_data[75] = {
    0.1690485637765703755422637438849e-01,
    0.8683252278406957990536107850768e-02,
@@ -177,69 +196,70 @@ static double dawa_data[75] = {
   -0.6120087296881677722911435593001e-31,
    0.1966024640193164686956230217896e-31
 };
-
-static struct gsl_sf_cheb_series daw_cs = {
-  daw_data,
-  20,
-  -1, 1,
-  (double *)0,
-  (double *)0
-};
-static struct gsl_sf_cheb_series daw2_cs = {
-  daw2_data,
-  44,
-  -1, 1,
-  (double *)0,
-  (double *)0
-};
-static struct gsl_sf_cheb_series dawa_cs = {
+static gsl_sf_cheb_series dawa_cs = {
   dawa_data,
-  74,
+  34, /* 74, */
   -1, 1,
   (double *)0,
-  (double *)0
+  (double *)0,
+  12
 };
 
 
+/*-*-*-*-*-*-*-*-*-*-*-* (semi)Private Implementations *-*-*-*-*-*-*-*-*-*-*-*/
+
 int
-gsl_sf_dawson_impl(double x, double * result)
+gsl_sf_dawson_impl(double x, gsl_sf_result * result)
 {
-  /* const double eps = GSL_MACH_EPS;   */              /* D1MACH(3) */
-  const double xsml = 1.225 * GSL_SQRT_MACH_EPS;        /* sqrt(1.5*eps) */
-  const double xbig = 1.0/(M_SQRT2*GSL_SQRT_MACH_EPS);  /* sqrt(0.5/eps) */
-  const double xmax = 0.1 * DBL_MAX;
+  const double xsml = 1.225 * GSL_SQRT_DBL_EPSILON;
+  const double xbig = 1.0/(M_SQRT2*GSL_SQRT_DBL_EPSILON);
+  const double xmax = 0.1 * GSL_DBL_MAX;
 
   const double y = fabs(x);
-  
+
   if(y < xsml) {
-    *result = x;
+    result->val = x;
+    result->err = 0.0;
     return GSL_SUCCESS;
   }
   else if(y < 1.0) {
-    *result = x * (0.75 + gsl_sf_cheb_eval(&daw_cs, 2.0*y*y - 1.0));
+    gsl_sf_result result_c;
+    gsl_sf_cheb_eval_impl(&daw_cs, 2.0*y*y - 1.0, &result_c);
+    result->val = x * (0.75 + result_c.val);
+    result->err = y * result_c.err;
     return GSL_SUCCESS;
   }
   else if(y < 4.0) {
-    *result = x * (0.25 + gsl_sf_cheb_eval(&daw2_cs, 0.125*y*y - 1.0));
+    gsl_sf_result result_c;
+    gsl_sf_cheb_eval_impl(&daw2_cs, 0.125*y*y - 1.0, &result_c);
+    result->val = x * (0.25 + result_c.val);
+    result->err = y * result_c.err;
     return GSL_SUCCESS;
   }
   else if(y < xbig) {
-    *result = (0.5 + gsl_sf_cheb_eval(&dawa_cs, 32.0/(y*y) - 1.0)) / x;
+    gsl_sf_result result_c;
+    gsl_sf_cheb_eval_impl(&dawa_cs, 32.0/(y*y) - 1.0, &result_c);
+    result->val = (0.5 + result_c.val) / x;
+    result->err = result_c.err / y;
     return GSL_SUCCESS;
   }
   else if(y < xmax) {
-    *result = 0.5/x;
+    result->val = 0.5/x;
+    result->err = result->val * GSL_DBL_EPSILON;
     return GSL_SUCCESS;
   }
   else {
-    *result = 0.0;
+    result->val = 0.0;
+    result->err = 0.0;
     return GSL_EUNDRFLW;
   }
 }
 
 
+/*-*-*-*-*-*-*-*-*-*-*-* Functions w/ Error Handling *-*-*-*-*-*-*-*-*-*-*-*/
+
 int
-gsl_sf_dawson_e(double x, double * result)
+gsl_sf_dawson_e(double x, gsl_sf_result * result)
 {
   int status = gsl_sf_dawson_impl(x, result);
   if(status != GSL_SUCCESS) {
@@ -247,15 +267,3 @@ gsl_sf_dawson_e(double x, double * result)
   }
   return status;
 }
-
-
-double
-gsl_sf_dawson(double x)
-{
-  double y;
-  int status = gsl_sf_dawson_impl(x, &y);
-  if(status != GSL_SUCCESS) {
-    GSL_WARNING("gsl_sf_dawson", status);
-  }
-  return y;
-}
