@@ -1,5 +1,5 @@
 /* Author:  G. Jungman
- * RCS:     $Id: gsl_sf_dawson.h,v 1.1 1998/08/18 22:27:18 jungman Exp $
+ * RCS:     $Id: gsl_sf_dawson.h,v 1.2 1998/12/14 01:12:58 jungman Exp $
  */
 #ifndef GSL_SF_DAWSON_H_
 #define GSL_SF_DAWSON_H_
@@ -11,9 +11,8 @@
  *
  * exceptions: GSL_EUNDRFLW;
  */
-int     gsl_sf_dawson_impl(double x, double * result);
-int     gsl_sf_dawson_e(double x, double * result);
-double  gsl_sf_dawson(double x);
+int     gsl_sf_dawson_impl(double x, gsl_sf_result * result);
+int     gsl_sf_dawson_e(double x, gsl_sf_result * result);
 
 
 #endif  /* !GSL_SF_DAWSON_H_ */
