@@ -1,4 +1,4 @@
-#include <stdio.h>
+#if !(defined(USES_LONGDOUBLE) && !defined(HAVE_PRINTF_LONGDOUBLE))
 
 int
 FUNCTION (gsl_block, fprintf) (FILE * stream, const ATOMIC * data,
@@ -64,3 +64,5 @@ FUNCTION (gsl_block, fscanf) (FILE * stream, ATOMIC * data,
 
   return GSL_SUCCESS;
 }
+
+#endif
