@@ -12,87 +12,107 @@ int status = 0;
 
 #define N 10000
 
+
 #define BASE_GSL_COMPLEX_LONG
 #include "templates_on.h"
 #include "test_complex_source.c"
+#ifdef HAVE_PRINTF_LONGDOUBLE
+#include "test_complex_io.c"
+#endif
 #include "templates_off.h"
 #undef  BASE_GSL_COMPLEX_LONG
 
+
 #define BASE_GSL_COMPLEX
 #include "templates_on.h"
 #include "test_complex_source.c"
+#include "test_complex_io.c"
 #include "templates_off.h"
 #undef  BASE_GSL_COMPLEX
 
 #define BASE_GSL_COMPLEX_FLOAT
 #include "templates_on.h"
 #include "test_complex_source.c"
+#include "test_complex_io.c"
 #include "templates_off.h"
 #undef  BASE_GSL_COMPLEX_FLOAT
 
 #define BASE_LONG_DOUBLE
 #include "templates_on.h"
 #include "test_source.c"
+#ifdef HAVE_PRINTF_LONGDOUBLE
+#include "test_io.c"
+#endif
 #include "templates_off.h"
 #undef  BASE_LONG_DOUBLE
 
 #define BASE_DOUBLE
 #include "templates_on.h"
 #include "test_source.c"
+#include "test_io.c"
 #include "templates_off.h"
 #undef  BASE_DOUBLE
 
 #define BASE_FLOAT
 #include "templates_on.h"
 #include "test_source.c"
+#include "test_io.c"
 #include "templates_off.h"
 #undef  BASE_FLOAT
 
 #define BASE_ULONG
 #include "templates_on.h"
 #include "test_source.c"
+#include "test_io.c"
 #include "templates_off.h"
 #undef  BASE_ULONG
 
 #define BASE_LONG
 #include "templates_on.h"
 #include "test_source.c"
+#include "test_io.c"
 #include "templates_off.h"
 #undef  BASE_LONG
 
 #define BASE_UINT
 #include "templates_on.h"
 #include "test_source.c"
+#include "test_io.c"
 #include "templates_off.h"
 #undef  BASE_UINT
 
 #define BASE_INT
 #include "templates_on.h"
 #include "test_source.c"
+#include "test_io.c"
 #include "templates_off.h"
 #undef  BASE_INT
 
 #define BASE_USHORT
 #include "templates_on.h"
 #include "test_source.c"
+#include "test_io.c"
 #include "templates_off.h"
 #undef  BASE_USHORT
 
 #define BASE_SHORT
 #include "templates_on.h"
 #include "test_source.c"
+#include "test_io.c"
 #include "templates_off.h"
 #undef  BASE_SHORT
 
 #define BASE_UCHAR
 #include "templates_on.h"
 #include "test_source.c"
+#include "test_io.c"
 #include "templates_off.h"
 #undef  BASE_UCHAR
 
 #define BASE_CHAR
 #include "templates_on.h"
 #include "test_source.c"
+#include "test_io.c"
 #include "templates_off.h"
 #undef  BASE_CHAR
 
@@ -119,7 +139,7 @@ main (void)
 
   test_text ();
   test_float_text ();
-#ifdef HAVE_LONGDOUBLE_PRINTF
+#ifdef HAVE_PRINTF_LONGDOUBLE
   test_long_double_text ();
 #endif
   test_ulong_text ();
@@ -132,7 +152,7 @@ main (void)
   test_char_text ();
   test_complex_text ();
   test_complex_float_text ();
-#ifdef HAVE_LONGDOUBLE_PRINTF
+#ifdef HAVE_PRINTF_LONGDOUBLE
   test_complex_long_double_text ();
 #endif
 
